@@ -1,6 +1,11 @@
+from unittest.case import skipIf
+
 from integration.helpers.base_test import BaseTest
+from integration.helpers.resource import current_region_does_not_support
+from integration.config.service_names import REST_API
 
 
+@skipIf(current_region_does_not_support([REST_API]), "Rest API is not supported in this testing region")
 class TestFunctionWithApi(BaseTest):
     def test_function_with_api(self):
         self.create_and_verify_stack("combination/function_with_api")
