@@ -23,7 +23,10 @@ class PullEventSource(ResourceMacro):
     # Event types that support `FilterCriteria`, stored as a list to keep the alphabetical order
     RESOURCE_TYPES_WITH_EVENT_FILTERING = ["DynamoDB", "Kinesis", "SQS"]
 
-    resource_type = None
+    # Note(xinhol): `PullEventSource` should have been an abstract class. Disabling the type check for the next
+    # line to avoid any potential behavior change.
+    # TODO: Make `PullEventSource` an abstract class and not giving `resource_type` initial value.
+    resource_type: str = None  # type: ignore
     requires_stream_queue_broker = True
     property_types = {
         "Stream": PropertyType(False, is_str()),
@@ -46,6 +49,7 @@ class PullEventSource(ResourceMacro):
         "FunctionResponseTypes": PropertyType(False, is_type(list)),
         "KafkaBootstrapServers": PropertyType(False, is_type(list)),
         "FilterCriteria": PropertyType(False, is_type(dict)),
+        "ConsumerGroupId": PropertyType(False, is_str()),
     }
 
     def get_policy_arn(self):
@@ -112,6 +116,17 @@ class PullEventSource(ResourceMacro):
             lambda_eventsourcemapping.SelfManagedEventSource = {
                 "Endpoints": {"KafkaBootstrapServers": self.KafkaBootstrapServers}
             }
+        if self.ConsumerGroupId:
+            consumer_group_id_structure = {"ConsumerGroupId": self.ConsumerGroupId}
+            if self.resource_type == "MSK":
+                lambda_eventsourcemapping.AmazonManagedKafkaConfig = consumer_group_id_structure
+            elif self.resource_type == "SelfManagedKafka":
+                lambda_eventsourcemapping.SelfManagedKafkaConfig = consumer_group_id_structure
+            else:
+                raise InvalidEventException(
+                    self.logical_id,
+                    "Property ConsumerGroupId not defined for resource of type {}.".format(self.resource_type),
+                )
 
         destination_config_policy = None
         if self.DestinationConfig:
@@ -188,6 +203,13 @@ class PullEventSource(ResourceMacro):
         if list(self.FilterCriteria.keys()) not in [[], ["Filters"]]:
             raise InvalidEventException(self.relative_id, "FilterCriteria field has a wrong format")
 
+    def validate_secrets_manager_kms_key_id(self):
+        if self.SecretsManagerKmsKeyId and not isinstance(self.SecretsManagerKmsKeyId, str):
+            raise InvalidEventException(
+                self.relative_id,
+                "Provided SecretsManagerKmsKeyId should be of type str.",
+            )
+
 
 class Kinesis(PullEventSource):
     """Kinesis event source."""
@@ -304,6 +326,7 @@ class MQ(PullEventSource):
             },
         }
         if self.SecretsManagerKmsKeyId:
+            self.validate_secrets_manager_kms_key_id()
             kms_policy = {
                 "Action": "kms:Decrypt",
                 "Effect": "Allow",
@@ -367,6 +390,7 @@ class SelfManagedKafka(PullEventSource):
             statements.append(vpc_permissions)
 
         if self.SecretsManagerKmsKeyId:
+            self.validate_secrets_manager_kms_key_id()
             kms_policy = self.get_kms_policy()
             statements.append(kms_policy)
 
