@@ -1,4 +1,6 @@
-﻿from samtranslator.public.sdk.resource import SamResourceType
+﻿from typing import Dict, List
+
+from samtranslator.public.sdk.resource import SamResourceType
 from samtranslator.public.intrinsics import is_intrinsics
 from samtranslator.swagger.swagger import SwaggerEditor
 
@@ -43,6 +45,7 @@ class Globals(object):
             "CodeSigningConfigArn",
             "Architectures",
             "EphemeralStorage",
+            "FunctionUrlConfig",
         ],
         # Everything except
         #   DefinitionBody: because its hard to reason about merge of Swagger dictionaries
@@ -80,6 +83,8 @@ class Globals(object):
         ],
         SamResourceType.SimpleTable.value: ["SSESpecification"],
     }
+    # unreleased_properties *must be* part of supported_properties too
+    unreleased_properties: Dict[str, List[str]] = {}
 
     def __init__(self, template):
         """
@@ -176,9 +181,7 @@ class Globals(object):
 
         globals = {}
         if not isinstance(globals_dict, dict):
-            raise InvalidGlobalsSectionException(
-                self._KEYWORD, "It must be a non-empty dictionary".format(self._KEYWORD)
-            )
+            raise InvalidGlobalsSectionException(self._KEYWORD, "It must be a non-empty dictionary")
 
         for section_name, properties in globals_dict.items():
             resource_type = self._make_resource_type(section_name)
@@ -195,14 +198,17 @@ class Globals(object):
             if not isinstance(properties, dict):
                 raise InvalidGlobalsSectionException(self._KEYWORD, "Value of ${section} must be a dictionary")
 
+            supported = self.supported_properties[resource_type]
+            supported_displayed = [
+                prop for prop in supported if prop not in self.unreleased_properties.get(resource_type, [])
+            ]
             for key, value in properties.items():
-                supported = self.supported_properties[resource_type]
                 if key not in supported:
                     raise InvalidGlobalsSectionException(
                         self._KEYWORD,
                         "'{key}' is not a supported property of '{section}'. "
                         "Must be one of the following values - {supported}".format(
-                            key=key, section=section_name, supported=supported
+                            key=key, section=section_name, supported=supported_displayed
                         ),
                     )
 
